# -*- mode: python; sh-basic-offset: 4; indent-tabs-mode: nil; -*-
# vim: set filetype=python sw=4 sts=4 expandtab autoindent:
#
#    Backupninja python reimplementation, based on original backupninja program
#    by riseup.net.
#    Copyright (C) 2010  Matthijs Kooijman <matthijs@stdin.nl>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

""" Running backup actions """

import logging as log

from backupninja import config
from backupninja import handlers

def run_all_actions(opts, global_config):
    """
    Run all defined actions.

    opts are the parsed commandline options, global_config is the parsed
    global configuration.
    """
    actions = config.list_actions(opts)
    actions.sort()

    for action in actions:
        run_action(action, opts, global_config)

def run_action(action, opts, global_config):
    """
    Run a single action. opts are the parsed commandline options,
    global_config is the parsed global configuration.
    """
    # Split the action filename
    parts = action.split('.', 2)
    if (len(parts) < 2):
        log.error('Invalid action filename: "%s". Should be in the form name.type, where type is a valid handler.')
        return
    (action_name, action_ty) = parts

    # Get the config for this action
    action_config = config.get_action_config(opts, action)

    try:
        # Create a handler for this action
        handler = handlers.create_handler(action_ty, action_config)
        # Run it
        handler.run()
        handler.finish()
    except Exception, e:
        log.error('Running action "%s" failed: %s', action, e)
